@@ -2,8 +2,8 @@ import asyncio
 import contextlib
 import functools
 import logging
-import sys
 import typing
+from contextvars import ContextVar
 from types import TracebackType
 from urllib.parse import SplitResult, parse_qsl, unquote, urlsplit
 
@@ -11,12 +11,7 @@ from sqlalchemy import text
 from sqlalchemy.sql import ClauseElement
 
 from databases.importer import import_from_string
-from databases.interfaces import ConnectionBackend, DatabaseBackend, TransactionBackend
-
-if sys.version_info >= (3, 7):  # pragma: no cover
-    import contextvars as contextvars
-else:  # pragma: no cover
-    import aiocontextvars as contextvars
+from databases.interfaces import DatabaseBackend, Record
 
 try:  # pragma: no cover
     import click
@@ -69,9 +64,7 @@ class Database:
         self._backend = backend_cls(self.url, **self.options)
 
         # Connections are stored as task-local state.
-        self._connection_context = contextvars.ContextVar(
-            "connection_context"
-        )  # type: contextvars.ContextVar
+        self._connection_context = ContextVar("connection_context")  # type: ContextVar
 
         # When `force_rollback=True` is used, we use a single global
         # connection, within a transaction that always rolls back.
@@ -120,7 +113,7 @@ class Database:
             self._global_transaction = None
             self._global_connection = None
         else:
-            self._connection_context = contextvars.ContextVar("connection_context")
+            self._connection_context = ContextVar("connection_context")
 
         await self._backend.disconnect()
         logger.info(
@@ -144,13 +137,13 @@ class Database:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.List[typing.Sequence]:
+    ) -> typing.List[Record]:
         async with self.connection() as connection:
             return await connection.fetch_all(query, values)
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Optional[typing.Sequence]:
+    ) -> typing.Optional[Record]:
         async with self.connection() as connection:
             return await connection.fetch_one(query, values)
 
@@ -182,11 +175,6 @@ class Database:
             async for record in connection.iterate(query, values):
                 yield record
 
-    def _new_connection(self) -> "Connection":
-        connection = Connection(self._backend)
-        self._connection_context.set(connection)
-        return connection
-
     def connection(self) -> "Connection":
         if self._global_connection is not None:
             return self._global_connection
@@ -194,23 +182,14 @@ class Database:
         try:
             return self._connection_context.get()
         except LookupError:
-            return self._new_connection()
+            connection = Connection(self._backend)
+            self._connection_context.set(connection)
+            return connection
 
     def transaction(
         self, *, force_rollback: bool = False, **kwargs: typing.Any
     ) -> "Transaction":
-        try:
-            connection = self._connection_context.get()
-            is_root = not connection._transaction_stack
-            if is_root:
-                newcontext = contextvars.copy_context()
-                get_conn = lambda: newcontext.run(self._new_connection)
-            else:
-                get_conn = self.connection
-        except LookupError:
-            get_conn = self.connection
-
-        return Transaction(get_conn, force_rollback=force_rollback, **kwargs)
+        return Transaction(self.connection, force_rollback=force_rollback, **kwargs)
 
     @contextlib.contextmanager
     def force_rollback(self) -> typing.Iterator[None]:
@@ -246,7 +225,7 @@ class Connection:
             try:
                 if self._connection_counter == 1:
                     await self._connection.acquire()
-            except Exception as e:
+            except BaseException as e:
                 self._connection_counter -= 1
                 raise e
         return self
@@ -265,14 +244,14 @@ class Connection:
 
     async def fetch_all(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.List[typing.Sequence]:
+    ) -> typing.List[Record]:
         built_query = self._build_query(query, values)
         async with self._query_lock:
             return await self._connection.fetch_all(built_query)
 
     async def fetch_one(
         self, query: typing.Union[ClauseElement, str], values: dict = None
-    ) -> typing.Optional[typing.Sequence]:
+    ) -> typing.Optional[Record]:
         built_query = self._build_query(query, values)
         async with self._query_lock:
             return await self._connection.fetch_one(built_query)
@@ -336,6 +315,9 @@ class Connection:
         return query
 
 
+_CallableType = typing.TypeVar("_CallableType", bound=typing.Callable)
+
+
 class Transaction:
     def __init__(
         self,
@@ -368,13 +350,13 @@ class Transaction:
         else:
             await self.commit()
 
-    def __await__(self) -> typing.Generator:
+    def __await__(self) -> typing.Generator[None, None, "Transaction"]:
         """
         Called if using the low-level `transaction = await database.transaction()`
         """
         return self.start().__await__()
 
-    def __call__(self, func: typing.Callable) -> typing.Callable:
+    def __call__(self, func: _CallableType) -> _CallableType:
         """
         Called if using `@database.transaction()` as a decorator.
         """
@@ -384,7 +366,7 @@ class Transaction:
             async with self:
                 return await func(*args, **kwargs)
 
-        return wrapper
+        return wrapper  # type: ignore
 
     async def start(self) -> "Transaction":
         self._connection = self._connection_callable()
